@@ -1,7 +1,8 @@
-// $Id: VerifyDlg.cpp,v 1.12 2000/10/25 23:06:52 rolandg Exp $
+// $Id: VerifyDlg.cpp,v 1.22 2002/01/31 15:45:38 widman Exp $
 //
 // KDat - a tar-based DAT archiver
-// Copyright (C) 1998  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 2001-2002  Lawrence Widman, kdat@cardiothink.com
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -28,7 +29,7 @@
 #include <qpushbutton.h>
 #include <qfile.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kprocess.h>
 #include <klocale.h>
 #include <kdebug.h>
@@ -57,13 +58,13 @@ VerifyDlg::VerifyDlg( const QString & workingDir, int fileno, const RangeList& r
           _done( FALSE )
 {
     // Calculate size of verify.
-    QListIterator<Range> i( _ranges.getRanges() );
+    QPtrListIterator<Range> i( _ranges.getRanges() );
     _archiveSize = 0;
     for ( ; i.current(); ++i ) {
         _archiveSize += i.current()->getEnd() - i.current()->getStart();
     }
     _archiveSize = ( _archiveSize + 1 ) / 2;
-    
+
     if ( _restore ) {
         setCaption( i18n( "KDat: Restore" ) );
         setIconText( i18n( "KDat: Restore" ) );
@@ -74,7 +75,11 @@ VerifyDlg::VerifyDlg( const QString & workingDir, int fileno, const RangeList& r
 
     resize( 500, 300 );
 
-    const int labelWidth = 96;
+    /* 2002-01-26 LEW: "Time remaining" was cut off in mid-"g" 
+       in BackupDlg.cpp, 
+       so we'll provide that plus some space beyond it. */
+    // const int labelWidth = 96;
+    const int labelWidth = 110;
 
     QFrame* f1 = new QFrame( this );
     f1->setFrameStyle( QFrame::Panel | QFrame::Sunken );
@@ -94,22 +99,22 @@ VerifyDlg::VerifyDlg( const QString & workingDir, int fileno, const RangeList& r
     _timeRemaining = new QLabel( i18n( "00:00:00" ), f2 );
     _timeRemaining->setFixedHeight( _timeRemaining->sizeHint().height() );
 
-    QLabel* lbl3 = new QLabel( i18n( "Total kbytes:" ), f1 );
+    QLabel* lbl3 = new QLabel( i18n( "Total KB:" ), f1 );
     lbl3->setFixedSize( labelWidth, lbl3->sizeHint().height() );
 
     QLabel* totalKbytes = new QLabel( Util::kbytesToString( _archiveSize ), f1 );
     totalKbytes->setFixedHeight( totalKbytes->sizeHint().height() );
 
-    QLabel* lbl4 = new QLabel( i18n( "Kbytes read:" ), f2 );
+    QLabel* lbl4 = new QLabel( i18n( "KB read:" ), f2 );
     lbl4->setFixedSize( labelWidth, lbl4->sizeHint().height() );
 
-    _kbytesRead = new QLabel( i18n( "0k" ), f2 );
+    _kbytesRead = new QLabel( i18n( "0KB" ), f2 );
     _kbytesRead->setFixedHeight( _kbytesRead->sizeHint().height() );
 
     QLabel* lbl5 = new QLabel( i18n( "Transfer rate:" ), f1 );
     lbl5->setFixedSize( labelWidth, lbl5->sizeHint().height() );
 
-    _transferRate = new QLabel( i18n( "0k/min" ), f1 );
+    _transferRate = new QLabel( i18n( "0KB/min" ), f1 );
     _transferRate->setFixedHeight( _transferRate->sizeHint().height() );
 
     QLabel* lbl6;
@@ -151,7 +156,7 @@ VerifyDlg::VerifyDlg( const QString & workingDir, int fileno, const RangeList& r
     l1_1->addStrut( 3 * lbl1->height() + 16 );
     l1_1->addWidget( f1 );
     l1_1->addWidget( f2 );
-    
+
     QVBoxLayout* l1_1_1 = new QVBoxLayout( f1, 4, 4 );
 
     QHBoxLayout* l1_1_1_1 = new QHBoxLayout();
@@ -221,7 +226,7 @@ void VerifyDlg::show()
     startTimer( 100 );
 
     _proc->start( KProcess::NotifyOnExit, KProcess::All );
-    
+
     QDialog::show();
 }
 
@@ -243,7 +248,10 @@ void VerifyDlg::slotStdout( KProcess*, char* buf, int len )
 {
     QString data;
     data.replace( 0, len, buf );
-    data[len] = '\0';
+    /* 2002-02-23 RG */
+    // data[len] = '\0';
+    data.truncate( len );
+    /* 2002-02-23 RG */
     _leftover += data;
 
     int newlineIndex;
@@ -269,7 +277,7 @@ void VerifyDlg::slotStdout( KProcess*, char* buf, int len )
                 _lastFileName = _leftover.left( newlineIndex );
             }
         }
-        
+
         _leftover.remove( 0, newlineIndex + 1 );
         QString tmp;
         tmp.setNum( _fileCount );
@@ -305,11 +313,17 @@ void VerifyDlg::timerEvent( QTimerEvent* )
     int bytesToRead;
     int count;
     char *buf = new char[Options::instance()->getTapeBlockSize()];
-    QListIterator<Range> i( _ranges.getRanges() );
+    QPtrListIterator<Range> i( _ranges.getRanges() );
     for ( ; ( !_done ) && ( !_aborted ) && ( i.current() ); ++i ) {
         // Move to the beginning of the next range.
         TapeDrive::instance()->seek( _fileno, i.current()->getStart() );
 
+	/* 2002-01-30 LEW */
+#ifdef DEBUG
+        printf("Seeking to next range: %d-%d\n", i.current()->getStart(), i.current()->getEnd());
+#endif /* DEBUG */
+	/* 2002-01-30 LEW */
+
         // Read in the records and forward them to tar.
         bytesToRead = ( i.current()->getEnd() - i.current()->getStart() ) * 512;
         while ( bytesToRead > 0 ) {
@@ -317,6 +331,11 @@ void VerifyDlg::timerEvent( QTimerEvent* )
 
             if ( count == 0 ) {
                 // I hope this means end-of-file.  Break out of the while loop, and process the next range.
+	      /* 2002-01-30 LEW */
+#ifdef DEBUG
+              printf("VerifyDlg::timerEvent count==0, so I'm skipping to the next range\n");
+#endif /* DEBUG */
+	      /* 2002-01-30 LEW */
                 break;
             }
 
@@ -327,8 +346,14 @@ void VerifyDlg::timerEvent( QTimerEvent* )
                 return;
             }
 
-            while ( ( !_done ) && ( !_aborted ) && ( !_wroteStdin ) ) KApplication::kApplication()->processEvents();
+            while ( ( !_done ) && ( !_aborted ) && ( !_wroteStdin ) )
+	         KApplication::kApplication()->processEvents();
             if ( _done || _aborted ) {
+	      /* 2002-01-30 LEW */
+#ifdef DEBUG
+              printf("VerifyDlg::timerEvent done/aborted, so I'm skipping to the next range\n");
+#endif /* DEBUG */
+	      /* 2002-01-30 LEW */
                 break;
             }
             _wroteStdin = FALSE;
@@ -356,7 +381,7 @@ void VerifyDlg::timerEvent( QTimerEvent* )
     // Send an EOF block to tar.
     memset( buf, 0, Options::instance()->getTapeBlockSize() );
     _proc->writeStdin( buf, Options::instance()->getTapeBlockSize() );
-    
+
     _proc->closeStdin();
     delete [] buf;
 }
@@ -365,10 +390,10 @@ void VerifyDlg::updateStats()
 {
     QString str;
     int elapsed = time( NULL ) - _startTime;
-                
+
     str= QString::fromUtf8( QCString().sprintf( i18n( "%02d:%02d:%02d" ).utf8(), elapsed / 3600, elapsed / 60 % 60, elapsed % 60 ) );
     _elapsedTime->setText( str );
-    
+
     int remain = 0;
     if ( (int)_totalKBytes > 0 ) {
         remain = (int)(( (float)_archiveSize - _totalKBytes ) * (float)elapsed / _totalKBytes);
@@ -378,10 +403,10 @@ void VerifyDlg::updateStats()
     }
     str = QString::fromUtf8( QCString().sprintf( i18n( "%02d:%02d:%02d" ).utf8(), remain / 3600, remain / 60 % 60, remain % 60 ) );
     _timeRemaining->setText( str );
-    
+
     str = Util::kbytesToString( (int)_totalKBytes );
     _kbytesRead->setText( str );
-    
+
     if ( elapsed > 0 ) {
         str = i18n( "%1/min" ).arg(Util::kbytesToString( (int)_totalKBytes * 60 / elapsed ) );
         _transferRate->setText( str );
