@@ -5,7 +5,7 @@
     Copyright (C) 1997-2000 Peter Putzer
                             putzer@kde.org
 
-	$Id: TopWidget.cpp,v 1.100 2000/12/11 17:48:33 putzer Exp $
+	$Id: TopWidget.cpp,v 1.107 2002/01/20 23:43:28 mhunter Exp $
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of version 2 of the GNU General Public License
@@ -30,18 +30,17 @@
 
 #include <ctype.h>
 
-#include <qpopmenu.h>
+#include <qpopupmenu.h>
 #include <qkeycode.h>
-#include <qmsgbox.h>
+#include <qmessagebox.h>
 #include <qfontmetrics.h>
 #include <qpainter.h>
-#include <qmultilinedit.h>
+#include <qmultilineedit.h>
 #include <qdatetime.h>
-#include <qprinter.h>
+#include <kprinter.h>
 #include <qpaintdevicemetrics.h>
 #include <qbuttongroup.h>
 #include <qclipboard.h>
-#include <qprintdialog.h>
 #include <qtooltip.h>
 #include <qcheckbox.h>
 #include <qhbox.h>
@@ -61,7 +60,7 @@
 #include <kaction.h>
 #include <kstdaction.h>
 #include <kdebug.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kglobal.h>
 #include <khelpmenu.h>
 #include <klocale.h>
@@ -87,6 +86,8 @@
 #include "OldView.h"
 #include "IOCore.h"
 #include "TopWidget.h"
+#include <qlabel.h>
+#include <kstatusbar.h>
 
 namespace Status
 {
@@ -333,8 +334,8 @@ void KSVTopLevel::slotAcceptChanges() {
   if (KMessageBox::Yes ==
       KMessageBox::warningYesNo(kapp->mainWidget(),
 				i18n("You're about to save the changes made to your init "
-				     "configuration.\nPlease realize that wrong settings can "
-				     "make your system hang on startup.\n\n"
+				     "configuration. Wrong settings can "
+				     "make your system hang on startup.\n"
 				     "Do you wish to continue?"),
 				i18n("Save Configuration"),
 				i18n("&Save"),
@@ -429,8 +430,8 @@ void KSVTopLevel::initStatusBar()
   connect (mAuth, SIGNAL (authChanged(bool)), mView, SLOT(multiplexEnabled(bool)));
   connect (mAuth, SIGNAL (authChanged(bool)), this, SLOT(writingEnabled(bool)));
 
-  QWhatsThis::add (authIconBox, i18n ("<p>When the lock is closed <img src=\"user|ksysv_locked\"/>, "\
-                                      "you haven't got the right " \
+  QWhatsThis::add (authIconBox, i18n ("<p>If the lock is closed <img src=\"user|ksysv_locked\"/>, "\
+                                      "you don't have the right " \
                                       "<strong>permissions</strong> to edit the init configuration.</p>" \
                                       "<p>Either restart %1 as root (or another more privileged user), " \
                                       "or ask your sysadmin to install %1 <em>suid</em> or " \
@@ -671,7 +672,7 @@ void KSVTopLevel::print()
 {
 // #define checkPage if (metrics.height() - y < fm.lineSpacing()) prt.newPage();
 
-//   static QPrinter prt;
+//   static KPrinter prt;
 //   prt.setDocName(kapp->aboutData()->programName() + " Configuration");
 //   prt.setCreator(kapp->aboutData()->programName());
 
@@ -789,19 +790,16 @@ void KSVTopLevel::print()
 
 void KSVTopLevel::printLog()
 {  
-  static QPrinter prt;
-  prt.setDocName(kapp->aboutData()->programName() + " Log File");
-  prt.setCreator(kapp->aboutData()->programName());
-
-  static QPrintDialog* dlg = new QPrintDialog (&prt, this, "KSysV Print Log Dialog");
-  dlg->setCaption(kapp->makeStdCaption (i18n("Print Log")));
+  KPrinter *prt = new KPrinter();
+  prt->setDocName(kapp->aboutData()->programName() + " Log File");
+  prt->setCreator(kapp->aboutData()->programName());
   
-  if (dlg->exec() == QDialog::Accepted)
+  if (prt->setup(this))
     {
       KBusyManager::self()->setBusy (true);
 
-      QPainter p (&prt);
-      QPaintDeviceMetrics pm (&prt);
+      QPainter p (prt);
+      QPaintDeviceMetrics pm (prt);
       const int height = pm.height();
       const int width = pm.width();
       
@@ -817,7 +815,7 @@ void KSVTopLevel::printLog()
         rheading.setWidth (&p, width);
         int tmp_h = rheading.height();
         QRegion region (0, y, width, tmp_h);
-        rheading.draw (&p, 0, y, region, palette(), 0L);
+        rheading.draw (&p, 0, y, region, colorGroup(), 0L);
 
         y += tmp_h;
         
@@ -827,7 +825,7 @@ void KSVTopLevel::printLog()
         rdate.setWidth (&p, width);
         tmp_h = rdate.height();
 	QRegion r2 (0, y, width, tmp_h); 
-        rdate.draw (&p, 0, y, r2, palette(), 0L);
+        rdate.draw (&p, 0, y, r2, colorGroup(), 0L);
 
         y += tmp_h;
       }
@@ -845,7 +843,7 @@ void KSVTopLevel::printLog()
                 break;
               
               QRegion region (0, y, width, tmp_h);
-              rich.draw (&p, 0, y, region, palette(), 0L);
+              rich.draw (&p, 0, y, region, colorGroup(), 0L);
 
               y += tmp_h;
               ++line;
@@ -856,7 +854,7 @@ void KSVTopLevel::printLog()
               kapp->processEvents();
             }
           
-          prt.newPage();
+          prt->newPage();
           y = 0;
         }
 
